@@ -1,5 +1,6 @@
 import math
 from pathlib import Path
+from warnings import warn
 
 import numpy as np
 import pandas as pd
@@ -48,7 +49,7 @@ class Configs(dict):
         Iterator[Config]
             Allow for iteration
         """
-        dir_lca = self["dir"] / "lca"
+        dir_lca = self["output_dir"] / "lca"
         samples = self["samples"].keys()
         for sample in samples:
             config = Config(self)
@@ -66,7 +67,7 @@ class Configs(dict):
 
             config["path_lca"] = dir_lca / f"{sample}.lca.txt.gz"
             config["path_lca_log"] = dir_lca / f"{sample}.log.txt"
-            config["path_tmp"] = config["dir"] / "tmp" / sample
+            config["path_tmp"] = config["output_dir"] / "tmp" / sample
             yield config
 
     def get_nth(self, n: int) -> Config:
@@ -105,47 +106,47 @@ class Configs(dict):
         return len(self["samples"].keys())
 
     def check_number_of_jobs(self) -> None:
-        """Compare the number of configs to the number of cores used."""
+        """Compare the number of configs to the number of parallel_samples used."""
 
-        cores = min(self["cores"], len(self["samples"]))
-        cores_pr_fit = self["cores_pr_fit"]
-        N_jobs = cores * cores_pr_fit
+        parallel_samples = min(self["parallel_samples"], len(self["samples"]))
+        cores_per_sample = self["cores_per_sample"]
+        N_jobs = parallel_samples * cores_per_sample
         max_cores = psutil.cpu_count(logical=True)
         max_cores_real = psutil.cpu_count(logical=False)
 
         if N_jobs > max_cores:
             logger.warning(
                 f"The total number of jobs {N_jobs} are higher "
-                f"than the number of cores {max_cores}. "
+                f"than the number of parallel_samples {max_cores}. "
                 f"Do not do this unless you know what you are doing. "
-                f"Try decreasing either 'cores' or 'cores-pr-fit'."
+                f"Try decreasing either 'parallel_samples' or 'parallel_samples-per-sample'."
             )
         elif N_jobs > max_cores_real:
             logger.info(
                 f"The total number of jobs {N_jobs} are higher "
-                f"than the real number of cores {max_cores_real} (non-logical). "
+                f"than the real number of parallel_samples {max_cores_real} (non-logical). "
                 f"This might decrease performance. "
             )
 
 
 def make_configs(
-    config_path: Optional[Path],
+    config_file: Optional[Path],
     log_port: Optional[int] = None,
     log_path: Optional[str] = None,
-    forced: bool = False,
+    force: bool = False,
 ) -> Configs:
     """Create an instance of Configs from a config file
 
     Parameters
     ----------
-    config_path
+    config_file
         The config file to load
     log_port
         Optional log port, by default None
     log_path
         Optional log path, by default None
-    forced
-        Whether or not the computations are forced, by default False
+    force
+        Whether or not the computations are force, by default False
 
     Returns
     -------
@@ -157,28 +158,28 @@ def make_configs(
         If not a proper config file
     """
 
-    if config_path is None:
-        config_path = Path("config.yaml")
+    if config_file is None:
+        config_file = Path("config.yaml")
 
-    if not config_path.exists():
+    if not config_file.exists():
         logger.error("Error! Please select a proper config file!")
         raise typer.Abort()
 
-    logger.info(f"Using {config_path} as config file.")
-    with open(config_path, "r") as file:
+    logger.info(f"Using {config_file} as config file.")
+    with open(config_file, "r") as file:
         d = yaml.safe_load(file)
 
+    d = update_old_config(d)
+
     d["log_port"] = log_port
     d["log_path"] = log_path
-    if forced:
-        d["forced"] = True
 
     d.setdefault("forward_only", False)
-    d.setdefault("cores_pr_fit", 1)
+    d.setdefault("cores_per_sample", 1)
     d.setdefault("damage_mode", "lca")
-    d.setdefault("forced", False)
+    d["force"] = force
 
-    paths = ["names", "nodes", "acc2tax", "dir", "config_path"]
+    paths = ["names", "nodes", "acc2tax", "output_dir", "config_file"]
     for path in paths:
         d[path] = Path(d[path])
     for key, val in d["samples"].items():
@@ -189,12 +190,53 @@ def make_configs(
             if val.isdigit():
                 d[key] = int(key)
 
+    d["custom_database"] = 0 if d["custom_database"] else 1
+
     return Configs(d)
 
 
 #%%
 
 
+def update_old_config(d: dict) -> dict:
+    if "version" in d:
+        # new version, not changing anything
+        return d
+
+    # updating the old version
+
+    logger.warning(
+        "Using an old version of the config file. Please remake the config file."
+    )
+
+    d_old2new = {
+        "metaDMG-lca": "metaDMG_cpp",
+        "minmapq": "min_mapping_quality",
+        "editdistmin": "min_edit_dist",
+        "editdistmax": "max_edit_dist",
+        "simscorelow": "min_similarity_score",
+        "simscorehigh": "max_similarity_score",
+        "weighttype": "weight_type",
+        "storage_dir": "output_dir",
+        "dir": "output_dir",
+        "fix_ncbi": "custom_database",
+        "cores": "parallel_samples",
+        "cores_per_sample": "cores_per_sample",
+        "config_path": "config_file",
+    }
+
+    d_new = {}
+    for key, value in d.items():
+        if key in d_old2new:
+            key = d_old2new[key]
+        d_new[key] = value
+    d_new.pop("forced")
+    return d_new
+
+
+#%%
+
+
 def downcast_dataframe(df, categories=None, fully_automatic=False):
 
     if categories is None:
